eigen: C++ template library for linear algebra
==============================================

Description
-----------

Eigen is a C++ template library for linear algebra: matrices, vectors, numerical
solvers, and related algorithms.


License
-------

MPL 2


Upstream Contact
----------------

https://eigen.tuxfamily.org/index.php?title=Main_Page#Requirements
